==> qgis_0.3.0.orig.tar.gz: qgis-0.3.0/src/qgsattributetabledisplay.h <==
/***************************************************************************
                          QgsAttributeTableDisplay.h  -  description
                             -------------------
    begin                : Sat Nov 23 2002
    copyright            : (C) 2002 by Gary E.Sherman
    email                : sherman at mrcc dot com
        Romans 3:23=>Romans 6:23=>Romans 5:8=>Romans 10:9,10=>Romans 12
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/* $Id */

#ifndef QGSATTRIBUTETABLEDISPLAY_H
#define QGSATTRIBUTETABLEDISPLAY_H

#include "qgsattributetablebase.uic.h"
class QgsAttributeTable;
/**
  *@author Gary E.Sherman
  */

class QgsAttributeTableDisplay:public QgsAttributeTableBase
{
  public:
	QgsAttributeTableDisplay();
	~QgsAttributeTableDisplay();
	QgsAttributeTable *table();
	void setTitle(QString title);
 signals:
	/**Is emitted before the widget deletes itself*/
	void deleted();
};

#endif

==> qgis_0.6.0.orig.tar.gz: qgis-0.6.0/src/qgsattributetabledisplay.h <==
/***************************************************************************
                          qgsattributetabledisplay.h  -  description
                             -------------------
    begin                : Sat Nov 23 2002
    copyright            : (C) 2002 by Gary E.Sherman
    email                : sherman at mrcc dot com
        Romans 3:23=>Romans 6:23=>Romans 5:8=>Romans 10:9,10=>Romans 12
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/* $Id: qgsattributetabledisplay.h,v 1.6 2004/10/16 21:59:14 gsherman Exp $ */

#ifndef QGSATTRIBUTETABLEDISPLAY_H
#define QGSATTRIBUTETABLEDISPLAY_H
#ifdef WIN32
#include "qgsattributetablebase.h"
#else
#include "qgsattributetablebase.uic.h"
#endif
class QgsAttributeTable;
/**
  *@author Gary E.Sherman
  */

class QgsAttributeTableDisplay:public QgsAttributeTableBase
{
  public:
	QgsAttributeTableDisplay();
	~QgsAttributeTableDisplay();
	QgsAttributeTable *table();
	void setTitle(QString title);
 signals:
	/**Is emitted before the widget deletes itself*/
	void deleted();
};

#endif
